# Indoor Air Quality sensor IAQ01

This repository contains all CAD files needed for making a Veles IAQ01 wired sensor, part of a family of [Veles Smart Household](#veles-smart-household) sensors.

## Basic properties

### Measured values

* Carbon dioxide
* Temperature
* Relative humidity
* Volatile Organic Compounds (VOC)
* PM (particulate matter) [optional extension]

### Connectivity

* RS-485 with Modbus

### Power requirements

* Input voltage: 5 - 30 V DC 

## Project files

* [Hardware](PCB)
    * Schematic and PCB ([KiCAD](https://www.kicad.org/) project) in [`PCB/iaq_wired_sensor.kicad_pro`](PCB/Project_Outputs/iaq_wired_sensor.kicad_pro)
    * PCB step model in [`PCB/3D_MODEL/iaq_wired_sensor.step`](PCB/3D_MODEL/iaq_wired_sensor.step)
    * Gerbers for PCB manufacturing in [`PCB/Project_Outputs/GERBERS`](PCB/Project_Outputs/GERBERS)
    * Schematic exported as PDF in [`PCB/Project_Outputs/Schematic/iaq_wired_sensor.pdf`](PCB/Project_Outputs/Schematic/iaq_wired_sensor.pdf)
    * Interactive HTML BOM file in [`PCB/Project_Outputs/iBOM/iaq_wired_sensor_rev1_ibom.html`](PCB/Project_Outputs/iBOM/iaq_wired_sensor_rev1_ibom.html)
* [Firmware](fw)
    * This is a [STM32Cube IDE](https://www.st.com/en/development-tools/stm32cubeide.html) project
    * Uses a number of git submodules - clone this repo with `--recursive` or use `git submodule update --init` to get them
* [Enclosure](Enclosure)
    * [FreeCAD](https://www.freecad.org/) project in [`Enclosure/IAQ_Sensor_Enclosure.FCStd`](Enclosure/IAQ_Sensor_Enclosure.FCStd) 
    * STL files in [`Enclosure/STLs`](Enclosure/STLs)
        * Printing tested on Prusa Mk2S
* [Documentation](Documentation)
    * Datasheet in [`Documentation/Datasheet/IAQ_Wired_Sensor_Datasheet.pdf`](Documentation/Datasheet/IAQ_Wired_Sensor_Datasheet.pdf)
    * Product flyer in [`Documentation/Product_Flyer/wired_iaw_sensor_flyer_rev1.pdf`](Documentation/Product_Flyer/wired_iaw_sensor_flyer_rev1.pdf)

## Images

<img src="PCB/Project_Outputs/3D_MODEL/Images/iaq_wired_sensor.png" alt="IAQ wired sensor render" width="25%" height="auto"><img src="Documentation/Datasheet/fig/iaq_wired_sensor.png" alt="Front view of the sensor" width="25%" height="auto">

## Veles Smart Household

This sensor is part of Veles Smart Household. Goal of this project is to create open hardware and software platform for measuring various quantities, not only related to indoor air quality:

* temperature
* humidity
* atmospheric pressure
* carbon dioxide (CO2)
* carbon monoxide (CO)
* volatile organic compounds (VOC)
* particulate matter (PM - dust particles)
* light intensity
* soil moisture

... and some more!

Sensors are connected either via RS-485 Modbus or wirelessly to central unit. Wireless sensors are currently in development. Central unit may be any anything that can read from the bus: any computer with RS-485 to USB converter (e.g. Raspberry Pi) or an actual PLC. Readout of the sensor is possible via Modbus: either using your own favourite application or using your Python package.

**We want this to be community effort! Come help us make something great!**

### Other Smart Household repositories

* [RHT wired sensor](https://gitea.veleslabs.org/veles_labs/rht_sensor_wired)
* [Python package](https://gitea.veleslabs.org/veles_labs/pyveles) for sensor readout and visualization (work in progress)
    * Can be installed using `pip install veles`

## Further reading 

If you need more data, check out the [datasheet](Documentation/Datasheet/IAQ_Wired_Sensor_Datasheet.pdf).

## Modbus register cheatsheet

### Input Registers

|Value|Register|
|---|---|
|CO2 			 | 30010|
|SHT4x 			 | 30011|
|RH SHT4x 		 | 30012|
|T SCD4x 		 | 30013|
|RH SCD4x 		 | 30014|
|T SHT4x SIGNED 	 | 30015|
|T SCD4x SIGNED 	 | 30016|

### Holding Registers

|Value|Register|
|---|---|
|LED ON 		 | 40001|
|LED BRIGHTNESS		 | 40002|
|LED SMOOTH		 | 40003|
|CO2 ALERT LIMIT1 	 | 40004|
|CO2 ALERT LIMIT2 	 | 40005|
|SCD4x T OFFSET	  	 | 40006|
|MODBUS ADDR  		 | 40007|

### Device Information Registers

|Value|Register|
|---|---|
|VENDOR NAME 		 | 30010|
|PRODUCT CODE 		 | 30011|
|REVISION 		 | 30012|
|PRODUCT NAME 		 | 30013|
|SERIAL NUMBER  	 | 30014|
